# Agenix

Библиотека для управления памятью диалогов в AI агентах с использованием Redis.

## Установка

```bash
pip install agenix
```

## Использование

### Основное использование

```python
from agenix.memory.redis_memory import RedisMemory, RedisMemoryArgs
from agenix.memory.schemas import Conversation, PairMessage

# Инициализация памяти
redis_memory = RedisMemory(RedisMemoryArgs(
    host="localhost",
    port=6379,
    db=0,
    context_pairs=2  # Количество пар сообщений в контексте
))

# Сохранение диалога
conversation = Conversation(messages=[
    PairMessage(
        human="Привет!",
        assistant="Здравствуйте! Как я могу вам помочь?"
    )
])
redis_memory.store_conversation("user_123", conversation)

# Получение диалога
conversation = redis_memory.get_conversation("user_123")

# Получение форматированной истории
history = redis_memory.get_format_conversation("user_123")

# Очистка истории
redis_memory.clear_conversation("user_123")
```

### Использование с LangChain

```python
from langchain_openai import OpenAI
from langchain_core.prompts import ChatPromptTemplate

model = OpenAI()
prompt = ChatPromptTemplate.from_messages([
    ("system", "You are a helpful assistant. История общения с пользователем: {history}"),
    ("user", "{input}"),
])
chain = prompt | model

async def process_user_message(user_id: str, message: str) -> str:
    conversation = redis_memory.get_conversation(user_id)
    if conversation is None:
        conversation = Conversation(messages=[])

    formatted_history = redis_memory.get_format_conversation(user_id)
    response = await chain.ainvoke({
        "history": formatted_history,
        "input": message
    })

    conversation.messages.append(PairMessage(
        human=message,
        assistant=response.content
    ))

    redis_memory.store_conversation(user_id, conversation)
    return response.content
```

## Параметры конфигурации

- `conversation_ttl`: Время жизни диалога в секундах (по умолчанию 3600)
- `host`: Хост Redis сервера (по умолчанию "localhost")
- `port`: Порт Redis сервера (по умолчанию 6379)
- `db`: Индекс базы данных Redis (по умолчанию 0)
- `context_pairs`: Максимальное количество пар сообщений в контексте (по умолчанию 2)

## Требования

- Python >= 3.8
- redis
- pydantic

## Лицензия

MIT
